# -*- coding: utf-8 -*-
from django.contrib import admin
from django.utils.translation import ugettext_lazy as _

from jmb.core.admin.options import ExtendibleModelAdmin
from jmb.press.models import AreaPress, Press, Source


class PressAdmin(ExtendibleModelAdmin):
    list_display = (
        'get_status_display', 'date_p', 'title', 'source','area',
        'ordering', 'get_edit_icon', 'get_delete_icon',
    )
    prepopulated_fields = {"slug": ("title",)}
    list_display_links = ("get_edit_icon",)
    fieldsets = (
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
            'classes': ('collapse',)
        }),
        (_("Ordering"), {
            'fields' : ('ordering',),
            'classes': ('collapse',)
        }),
        (None, {'fields': (
            'status', 'title', 'area', 'date_p', 'slug',
            'source', 'file', 'abstract', 'keywords',
        )}),
        (_("SEO settings"), {
            'fields' : ('page_title','meta_description','meta_keywords'),
            'classes': ('collapse',)
        }),
        )
    save_on_top = True
    default_group_by = 'area'

class AreaPressAdmin(ExtendibleModelAdmin):
    list_display = (
        'get_status_display', 'name', 'slug',
        'get_edit_icon', 'get_delete_icon',
        )
    prepopulated_fields = {"slug": ("name",)}
    list_display_links = ("get_edit_icon",)
    fieldsets = (
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
            'classes': ('collapse',)
        }),
        (_("Ordering"), {
            'fields' : ('ordering',),
            'classes': ('collapse',)
        }),
        (None, {'fields': (
            'status', 'name','slug',
        )}),
    )
    save_on_top = True

class SourceAdmin(ExtendibleModelAdmin):
    list_display = (
        'get_status_display', 'name', 'slug',
        'get_edit_icon', 'get_delete_icon',
        )
    prepopulated_fields = {"slug": ("name",)}
    list_display_links = ("get_edit_icon",)
    fieldsets = (
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
            'classes': ('collapse',)
        }),
        (_("Ordering"), {
            'fields' : ('ordering',),
            'classes': ('collapse',)
        }),
        (None, {'fields': (
            'status', 'name','slug',
            )})
        )
    save_on_top = True



admin.site.register(AreaPress,AreaPressAdmin)
admin.site.register(Source,SourceAdmin)
admin.site.register(Press, PressAdmin)
