# -*- coding: utf-8 -*-

from django.db import models
from django.conf import settings
from django.utils.translation import ugettext_lazy as _

from cms.models.pluginmodel import CMSPlugin

class PressListSettings(CMSPlugin):
    active = models.BooleanField(
        _("Active"),
        default=True,
    )
    area_slugs_included = models.CharField(
        _("Area slugs included"),
        max_length=150,
        blank=True,
        help_text=_("(Optional) Including press area slug(s), separated by ','")
    )
    source_slugs_included = models.CharField(
        _("Source slugs included"),
        max_length=150,
        blank=True,
        help_text=_("(Optional) Including press source slug(s), separated by ','")
    )
    slugs_included = models.CharField(
        _("Slugs included"),
        max_length=100,
        blank=True,
        help_text=_("(Optional) Including press slug(s), separated by ','")
    )
    area_slugs_excluded = models.CharField(
        _("Area slugs excluded"),
        max_length=100,
        blank=True,
        help_text=_("(Optional) Excluding press area slug(s), separated by ','")
    )
    source_slugs_excluded = models.CharField(
        _("Source slugs excluded"),
        max_length=100,
        blank=True,
        help_text=_("(Optional) Excluding press source slug(s), separated by ','")
    )
    slugs_excluded = models.CharField(
        _("Slugs excluded"),
        max_length=150,
        blank=True,
        help_text=_("(Optional) Excluding press slug(s), separated by ','")
    )
    objects_per_page = models.IntegerField(
        _("Items per page"),
        default=10
    )
    ordering = models.CharField(
        _("Ordering"),
        max_length=100,
        default='ordering, -date_p, title'
    )
    template_name = models.CharField(
        max_length=100,
        choices=settings.PRESS_CMSPLUGIN_PRESSLIST_TEMPLATES,
        default="press/cms_plugins/press_list.html",
    )

    def __unicode__(self):
        name = "Press list - %s" %self.id
        if self.active:
            return "%s - ON" % name
        else:
            return "%s - OFF" % name

    class Meta:
        app_label = "press"

class PressListPerAreaSettings(CMSPlugin):
    active = models.BooleanField(
        _("Active"),
        default=True,
    )
    area_slugs_included = models.CharField(
        _("Area slugs included"),
        max_length=150,
        blank=True,
        help_text=_("(Optional) Including press area slug(s), separated by ','")
    )
    source_slugs_included = models.CharField(
        _("Source slugs included"),
        max_length=150,
        blank=True,
        help_text=_("(Optional) Including press source slug(s), separated by ','")
    )
    slugs_included = models.CharField(
        _("Slugs included"),
        max_length=100,
        blank=True,
        help_text=_("(Optional) Including press slug(s), separated by ','")
    )
    area_slugs_excluded = models.CharField(
        _("Area slugs excluded"),
        max_length=100,
        blank=True,
        help_text=_("(Optional) Excluding press area slug(s), separated by ','")
    )
    source_slugs_excluded = models.CharField(
        _("Source slugs excluded"),
        max_length=100,
        blank=True,
        help_text=_("(Optional) Excluding press source slug(s), separated by ','")
    )
    slugs_excluded = models.CharField(
        _("Slugs excluded"),
        max_length=150,
        blank=True,
        help_text=_("(Optional) Excluding press slug(s), separated by ','")
    )
    press_per_area = models.IntegerField(
        _("Press per area"),
        default=10
    )
    objects_per_page = models.IntegerField(
        _("Items per page"),
        default=10
    )
    ordering_per_area = models.CharField(
        _("Ordering per area"),
        max_length=100,
        default='ordering, name'
    )
    ordering_per_press = models.CharField(
        _("Ordering per press"),
        max_length=100,
        default='ordering, -date_p, title'
    )
    template_name = models.CharField(
        max_length=100,
        choices=settings.PRESS_CMSPLUGIN_PRESSLISTPERAREA_TEMPLATES,
        default="press/cms_plugins/press_list_per_area.html",
    )

    def __unicode__(self):
        name = "Press list per Area - %s" %self.id
        if self.active:
            return "%s - ON" % name
        else:
            return "%s - OFF" % name

    class Meta:
        app_label = "press"

class PressListPerSourceSettings(CMSPlugin):
    active = models.BooleanField(
        _("Active"),
        default=True,
    )
    area_slugs_included = models.CharField(
        _("Area slugs included"),
        max_length=150,
        blank=True,
        help_text=_("(Optional) Including press area slug(s), separated by ','")
    )
    source_slugs_included = models.CharField(
        _("Source slugs included"),
        max_length=150,
        blank=True,
        help_text=_("(Optional) Including press source slug(s), separated by ','")
    )
    slugs_included = models.CharField(
        _("Slugs included"),
        max_length=100,
        blank=True,
        help_text=_("(Optional) Including press slug(s), separated by ','")
    )
    area_slugs_excluded = models.CharField(
        _("Area slugs excluded"),
        max_length=100,
        blank=True,
        help_text=_("(Optional) Excluding press area slug(s), separated by ','")
    )
    source_slugs_excluded = models.CharField(
        _("Source slugs excluded"),
        max_length=100,
        blank=True,
        help_text=_("(Optional) Excluding press source slug(s), separated by ','")
    )
    slugs_excluded = models.CharField(
        _("Slugs excluded"),
        max_length=150,
        blank=True,
        help_text=_("(Optional) Excluding press slug(s), separated by ','")
    )
    press_per_source = models.IntegerField(
        _("Press per source"),
        default=10
    )
    objects_per_page = models.IntegerField(
        _("Items per page"),
        default=10
    )
    ordering_per_source = models.CharField(
        _("Ordering per source"),
        max_length=100,
        default='ordering, name'
    )
    ordering_per_press = models.CharField(
        _("Ordering per press"),
        max_length=100,
        default='ordering, -date_p, title'
    )
    template_name = models.CharField(
        max_length=100,
        choices=settings.PRESS_CMSPLUGIN_PRESSLISTPERSOURCE_TEMPLATES,
        default="press/cms_plugins/press_list_per_source.html",
    )

    def __unicode__(self):
        name = "Press list per Source - %s" %self.id
        if self.active:
            return "%s - ON" % name
        else:
            return "%s - OFF" % name

    class Meta:
        app_label = "press"

class PressSearchSettings(CMSPlugin):
    form = models.CharField(
        _("Form"),
        max_length=100,
        choices=settings.PRESS_FORM_CLASSES,
        default="jmb.press.forms.SearchPressForm",
    )
    template_name = models.CharField(
        max_length=100,
        choices=settings.PRESS_CMSPLUGIN_SEARCH_TEMPLATES,
        default="press/cms_plugins/search.html"
    )

    class Meta:
        app_label = "press"

    def __unicode__(self):
        return self.template_name