# -*- coding: utf-8 -*-

from django.core.paginator import Paginator
from django.utils.translation import ugettext as _
from django.db.models import Q

from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from jmb.core.utils.functions import import_class
from jmb.press.models import Press, AreaPress, Source
from jmb.press.cms.models import PressListSettings, PressListPerAreaSettings, PressListPerSourceSettings, PressSearchSettings


class PressListPlugin(CMSPluginBase):
    model = PressListSettings
    name = _("Press List")
    module = _("Press")

    def render(self, context, instance, placeholder):

        self.render_template = instance.template_name
        ordering = instance.ordering.lower().replace(" ","").split(",")
        objects = Press.objects.filter(status=1)
        page = 1

        ## inclusioni
        if instance.area_slugs_included:
            area_slugs = instance.area_slugs_included.lower().replace(" ","").split(",")
            objects = objects.filter(area__slug__in = area_slugs)
        if instance.source_slugs_included:
            source_slugs = instance.source_slugs_included.lower().replace(" ","").split(",")
            objects = objects.filter(source__slug__in = source_slugs)
        if instance.slugs_included:
            slugs = instance.slugs_included.lower().replace(" ","").split(",")
            objects = objects.filter(slug__in = slugs)

        ## esclusioni
        if instance.slugs_excluded:
            excluded_slugs = instance.slugs_excluded.lower().replace(" ","").split(",")
            objects = objects.exclude(slug__in = excluded_slugs)
        if instance.area_slugs_excluded:
            excluded_area_slugs = instance.area_slugs_excluded.lower().replace(" ","").split(",")
            objects = objects.exclude(area__slug__in = excluded_area_slugs)
        if instance.source_slugs_excluded:
            excluded_source_slugs = instance.source_slugs_excluded.lower().replace(" ","").split(",")
            objects = objects.exclude(source__slug__in = excluded_source_slugs)

        objects = objects.order_by(*ordering)

        request = context['request']
        par_get = {}
        query_string = None

        if request.GET:
            for key in request.GET.keys():
                if request.GET.get(key) != "":
                    par_get[key] = request.GET.get(key)

            # query string parameters
            if 'obj' in par_get and par_get['obj'] == 'press':
                query_dict = {}
                query_list = []
                for term in request.META['QUERY_STRING'].split("&"):
                    query_dict[term.split("=")[0]] = term.split("=")[1]
                for key, value in query_dict.items():
                    if not key == 'page':
                        query_list.append(key+"="+value)
                query_string = "&".join(query_list)

            if "page" in par_get and par_get['obj_page'] == 'press':
                page = par_get['page']

            # cancellazione per evitare interferenze con altre ricerche
            if "page" in par_get:
                del par_get['page']
            # cancellazione per evitare interferenze con altre ricerche
            if "obj_page" in par_get:
                del par_get['obj_page']


            if "obj" in par_get and par_get['obj'] == 'press':
                par_get.pop('obj')
                try:
                    objects = objects.filter(**par_get)
                except Exception, e:
                    pass

        paginator = Paginator(objects, instance.objects_per_page)
        objects = paginator.page(page)

        context.update({
            'objects': objects,
            'instance': instance,
            'placeholder': placeholder,
            'query_string':query_string
            })
        return context

plugin_pool.register_plugin(PressListPlugin)

class PressListPerAreaPlugin(CMSPluginBase):
    model = PressListPerAreaSettings
    name = _("Press List Per Area")
    module = _("Press")

    def render(self, context, instance, placeholder):

        self.render_template = instance.template_name
        ordering_per_area = instance.ordering_per_area.lower().replace(" ","").split(",")
        ordering_per_press = instance.ordering_per_press.lower().replace(" ","").split(",")

        areas = AreaPress.objects.filter(status=1).order_by(*ordering_per_area)
        area_list = []
        objects = Press.objects.filter(status=1)

        page = 1

        ## inclusioni
        if instance.area_slugs_included:
            area_slugs = instance.area_slugs_included.lower().replace(" ","").split(",")
            objects = objects.filter(area__slug__in = area_slugs)
        if instance.source_slugs_included:
            source_slugs = instance.source_slugs_included.lower().replace(" ","").split(",")
            objects = objects.filter(source__slug__in = source_slugs)
        if instance.slugs_included:
            slugs = instance.slugs_included.lower().replace(" ","").split(",")
            objects = objects.filter(slug__in = slugs)

        ## esclusioni
        if instance.slugs_excluded:
            excluded_slugs = instance.slugs_excluded.lower().replace(" ","").split(",")
            objects = objects.exclude(slug__in = excluded_slugs)
        if instance.area_slugs_excluded:
            excluded_area_slugs = instance.area_slugs_excluded.lower().replace(" ","").split(",")
            objects = objects.exclude(area__slug__in = excluded_area_slugs)
        if instance.source_slugs_excluded:
            excluded_source_slugs = instance.source_slugs_excluded.lower().replace(" ","").split(",")
            objects = objects.exclude(source__slug__in = excluded_source_slugs)

        objects = objects.order_by(*ordering_per_press)

        request = context['request']
        par_get = {}
        query_string = None

        if request.GET:
            for key in request.GET.keys():
                if request.GET.get(key) != "":
                    par_get[key] = request.GET.get(key)

            # query string parameters
            if 'obj' in par_get and par_get['obj'] == 'press':
                query_dict = {}
                query_list = []
                for term in request.META['QUERY_STRING'].split("&"):
                    query_dict[term.split("=")[0]] = term.split("=")[1]
                for key, value in query_dict.items():
                    if not key == 'page':
                        query_list.append(key+"="+value)
                query_string = "&".join(query_list)

            if "page" in par_get and par_get['obj_page'] == 'area':
                page = par_get['page']

            # cancellazione per evitare interferenze con altre ricerche
            if "page" in par_get:
                del par_get['page']

            # cancellazione per evitare interferenze con altre ricerche
            if "obj_page" in par_get:
                del par_get['obj_page']

            if "obj" in par_get and par_get['obj'] == 'press':
                par_get.pop('obj')
                try:
                    objects = objects.filter(**par_get)
                except Exception, e:
                    pass

        # paginator = Paginator(areas, instance.objects_per_page)
        # areas = paginator.page(page)

        for area in areas:
            press_for_area = objects.filter(area=area)
            if press_for_area.count()>0:
                area_dict = {
                    'area': area,
                    'press': press_for_area[0:instance.press_per_area],
                    'press_count': press_for_area.count()
                }
                area_list.append(area_dict)

        paginator = Paginator(area_list, instance.objects_per_page)
        area_list = paginator.page(page)


        context.update({
            'area_list': area_list,
            'instance': instance,
            'placeholder': placeholder,
            'query_string':query_string
        })
        return context

plugin_pool.register_plugin(PressListPerAreaPlugin)

class PressListPerSourcePlugin(CMSPluginBase):
    model = PressListPerSourceSettings
    name = _("Press List Per Source")
    module = _("Press")

    def render(self, context, instance, placeholder):

        self.render_template = instance.template_name
        ordering_per_source = instance.ordering_per_source.lower().replace(" ","").split(",")
        ordering_per_press = instance.ordering_per_press.lower().replace(" ","").split(",")

        sources = Source.objects.filter(status=1).order_by(*ordering_per_source)
        source_list = []
        objects = Press.objects.filter(status=1)

        page = 1

        ## inclusioni
        if instance.area_slugs_included:
            area_slugs = instance.area_slugs_included.lower().replace(" ","").split(",")
            objects = objects.filter(area__slug__in = area_slugs)
        if instance.source_slugs_included:
            source_slugs = instance.source_slugs_included.lower().replace(" ","").split(",")
            objects = objects.filter(source__slug__in = source_slugs)
        if instance.slugs_included:
            slugs = instance.slugs_included.lower().replace(" ","").split(",")
            objects = objects.filter(slug__in = slugs)

        ## esclusioni
        if instance.slugs_excluded:
            excluded_slugs = instance.slugs_excluded.lower().replace(" ","").split(",")
            objects = objects.exclude(slug__in = excluded_slugs)
        if instance.area_slugs_excluded:
            excluded_area_slugs = instance.area_slugs_excluded.lower().replace(" ","").split(",")
            objects = objects.exclude(area__slug__in = excluded_area_slugs)
        if instance.source_slugs_excluded:
            excluded_source_slugs = instance.source_slugs_excluded.lower().replace(" ","").split(",")
            objects = objects.exclude(source__slug__in = excluded_source_slugs)

        objects = objects.order_by(*ordering_per_press)

        request = context['request']
        par_get = {}
        query_string = None

        if request.GET:
            for key in request.GET.keys():
                if request.GET.get(key) != "":
                    par_get[key] = request.GET.get(key)

            if 'obj' in par_get and par_get['obj'] == 'press':
                query_dict = {}
                query_list = []
                for term in request.META['QUERY_STRING'].split("&"):
                    query_dict[term.split("=")[0]] = term.split("=")[1]
                for key, value in query_dict.items():
                    if key != 'page' and key != 'obj_page' :
                        query_list.append(key+"="+value)
                query_string = "&".join(query_list)

            if "page" in par_get and par_get['obj_page'] == 'source':
                page = par_get['page']

            # cancellazione per evitare interferenze con altre ricerche
            if "page" in par_get:
                del par_get['page']
                # cancellazione per evitare interferenze con altre ricerche
            if "obj_page" in par_get:
                del par_get['obj_page']

            if "obj" in par_get and par_get['obj'] == 'press':
                par_get.pop('obj')
                try:
                    objects = objects.filter(**par_get)
                except Exception, e:
                    pass



        for source in sources:
            press_for_source = objects.filter(source=source)
            if press_for_source.count()>0:
                source_dict = {
                    'source': source, 'press': press_for_source[0:instance.press_per_source],
                    'press_count': press_for_source.count()
                }
                source_list.append(source_dict)

        paginator = Paginator(source_list, instance.objects_per_page)
        source_list = paginator.page(page)

        context.update({
            'source_list': source_list,
            'instance': instance,
            'placeholder': placeholder,
            'query_string':query_string
            })
        return context

plugin_pool.register_plugin(PressListPerSourcePlugin)

class PressSearchPlugin(CMSPluginBase):

    model = PressSearchSettings
    name = _("Press Search")
    module = _("Press")

    def render(self, context, instance, placeholder):
        request = context['request']
        self.render_template = instance.template_name
        form_class = import_class(instance.form)
        try:
            if request.GET:
                form = form_class(request.GET)
            else:
                form = form_class()
        except:
            form = form_class()
        context.update({
            'form':form,
            'instance': instance,
            'placeholder': placeholder,
        })
        return context

plugin_pool.register_plugin(PressSearchPlugin)
