from django.core.urlresolvers import reverse
from django.db import models
from django.conf import settings
from django.utils.translation import ugettext_lazy as _
from django_extensions.db.fields import AutoSlugField
from jmb.core.db.models import DateModel, UserModel, StatusModel, OrderedModel, SEOModel
from jmb.i18n.models import TranslationModel, I18NModel
from jmb.core.db.fields import HTMLField, HTMLFieldTinyMCE

###################################
## MODELS                          #
###################################
class AreaPress(DateModel, UserModel, OrderedModel, StatusModel):
    """
    Un contenitore di notizie.
    """
    name = models.CharField(
        unique = True,
        max_length = 100,
        db_index = True,
        verbose_name = _('Name')
    )
    slug = models.SlugField(
        unique=True,
        max_length = 100,
        db_index=True,
        verbose_name=_('Slug')
    )

    def __unicode__(self):
        return u"%s" % self.name

    class Meta:
        verbose_name = _("Area")
        verbose_name_plural = _('Areas')

class Source(DateModel, UserModel, OrderedModel, StatusModel):
    name = models.CharField(
        unique = True,
        max_length = 100,
        db_index = True,
        verbose_name = _('Name')
    )
    slug = models.SlugField(
        max_length = 100,
        db_index = True,
        verbose_name = _('Slug')
    )

    class Meta:
        verbose_name = _("Source")
        verbose_name_plural = _("Sources")
        ordering = ['name',]

    def __unicode__(self):
        return u"%s" % self.name


class Press(DateModel, UserModel, OrderedModel, StatusModel, SEOModel):

    @classmethod
    def get_years(cls, desc=True):
        output = []
        press_qs = Press.objects.filter(status=1)
        for d in press_qs.dates('date_p','year', order='DESC' if desc else 'ASC'):
            output.append((str(d.year),str(d.year)))
        return output

    @classmethod
    def get_months(cls):
        return [
            ("1", _("January")),
            ("2", _("February")),
            ("3", _("March")),
            ("4", _("April")),
            ("5", _("May")),
            ("6", _("June")),
            ("7", _("July")),
            ("8", _("August")),
            ("9", _("September")),
            ("10", _("October")),
            ("11", _("November")),
            ("12", _("December"))
    ]

    date_p = models.DateField(
        db_index = True,
        verbose_name = _("Date")
    )
    title = models.CharField(
        max_length = 300,
        db_index = True,
        verbose_name = _("Title")
    )
    slug = models.SlugField(
        max_length = 100,
        db_index = True,
        verbose_name = _('Slug'),
    )
    source = models.ForeignKey(
        Source,
        null = True, blank = True,
        db_index = True,
        related_name = "press",
        verbose_name = _("Source"),
    )
    file = models.FileField (
        null = True, blank = True,
        upload_to = settings.PRESS_PRESS_FILE_UPLOAD_TO,
        verbose_name = _("File"),
    )
    abstract = models.TextField (
        null = True, blank = True,
        verbose_name = _("Abstract"),
    )
    keywords = models.CharField(
        null = True, blank = True,
        max_length = 200,
        db_index = True,
        verbose_name = _("Keywords"),
    )
    area = models.ForeignKey(
        AreaPress,
        related_name = "press",
        verbose_name=_("Area press")
    )


    class Meta:
        verbose_name = _("Press")
        verbose_name_plural = _("Press")
        ordering = ['ordering', '-date_p','title']

    def __unicode__(self):
        return u"%s" % self.title

#import cms stuffs
if settings.CMS_ENABLED:
    import jmb.press.cms.plugins
    import jmb.press.cms.app

